package com.link.core.parserplugin.util;

import java.lang.reflect.AccessibleObject;
import java.lang.reflect.Array;
import java.lang.reflect.Field;
import java.lang.reflect.Modifier;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.util.Calendar;
import java.util.Collection;
import java.util.Date;
import java.util.Iterator;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

public class ParserUtil {
   private static final ConcurrentHashMap<Class, Field[]> FIELDS_CAHCE = new ConcurrentHashMap();
   private static final String SPLIT_STR = "_";

   public static boolean isEmpty(Object obj) {
      if (null == obj) {
         return true;
      } else if (obj instanceof String) {
         return ((String)obj).length() == 0;
      } else {
         Class cl = obj.getClass();
         if (cl.isArray()) {
            int len = Array.getLength(obj);
            return len == 0;
         } else if (obj instanceof Collection) {
            Collection tempCol = (Collection)obj;
            return tempCol.isEmpty();
         } else if (obj instanceof Map) {
            Map tempMap = (Map)obj;
            return tempMap.isEmpty();
         } else {
            return false;
         }
      }
   }

   private static int getHashCode(String buf) {
      int hash = 5381;

      for(int len = buf.length(); len-- > 0; hash = (hash << 5) + hash + buf.charAt(len)) {
      }

      return hash;
   }

   public static String getUniqueHashStr(Object obj) {
      return getMiscHashCode(toString(obj));
   }

   public static String getMiscHashCode(String str) {
      if (null != str && str.length() != 0) {
         int originSize = 20;
         if (str.length() <= originSize) {
            return str;
         } else {
            StringBuilder tmp = new StringBuilder();
            tmp.append(str.hashCode()).append("_").append(getHashCode(str));
            int mid = str.length() / 2;
            String str1 = str.substring(0, mid);
            String str2 = str.substring(mid);
            tmp.append("_").append(str1.hashCode());
            tmp.append("_").append(str2.hashCode());
            return tmp.toString();
         }
      } else {
         return "";
      }
   }

   public static boolean isPrimitive(Object obj) {
      boolean rv = obj.getClass().isPrimitive() || obj instanceof String || obj instanceof Integer || obj instanceof Long || obj instanceof Byte || obj instanceof Character || obj instanceof Boolean || obj instanceof Short || obj instanceof Float || obj instanceof Double || obj instanceof BigDecimal || obj instanceof BigInteger;
      return rv;
   }

   public static String toString(Object obj) {
      if (obj == null) {
         return "null";
      } else {
         Class cl = obj.getClass();
         if (isPrimitive(obj)) {
            return String.valueOf(obj);
         } else if (obj instanceof Enum) {
            return ((Enum)obj).name();
         } else if (obj instanceof Date) {
            return String.valueOf(((Date)obj).getTime());
         } else if (obj instanceof Calendar) {
            return String.valueOf(((Calendar)obj).getTime().getTime());
         } else {
            String r;
            if (cl.isArray()) {
               r = "[";
               int len = Array.getLength(obj);

               for(int i = 0; i < len; ++i) {
                  if (i > 0) {
                     r = r + ",";
                  }

                  Object val = Array.get(obj, i);
                  r = r + toString(val);
               }

               return r + "]";
            } else {
               int i;
               String comma;
               Object val;
               if (obj instanceof Collection) {
                  Collection tempCol = (Collection)obj;
                  Iterator it = tempCol.iterator();
                  comma = "[";

                  for(i = 0; it.hasNext(); ++i) {
                     if (i > 0) {
                        comma = comma + ",";
                     }

                     val = it.next();
                     comma = comma + toString(val);
                  }

                  return comma + "]";
               } else if (obj instanceof Map) {
                  Map tempMap = (Map)obj;
                  String r = "{";
                  Iterator it = tempMap.entrySet().iterator();

                  while(it.hasNext()) {
                     Map.Entry entry = (Map.Entry)it.next();
                     val = entry.getKey();
                     r = r + toString(val);
                     r = r + "=";
                     Object val = entry.getValue();
                     r = r + toString(val);
                     if (it.hasNext()) {
                        r = r + ",";
                     }
                  }

                  return r + "}";
               } else if (obj instanceof Class) {
                  Class tmpCls = (Class)obj;
                  return tmpCls.getName();
               } else {
                  r = cl.getName();

                  do {
                     Field[] fields = (Field[])FIELDS_CAHCE.get(cl);
                     if (null == fields) {
                        fields = cl.getDeclaredFields();
                        if (null != fields) {
                           AccessibleObject.setAccessible(fields, true);
                        }

                        FIELDS_CAHCE.put(cl, fields);
                     }

                     if (null != fields && fields.length != 0) {
                        r = r + "[";
                        Field[] var4 = fields;
                        i = fields.length;

                        for(int var6 = 0; var6 < i; ++var6) {
                           Field f = var4[var6];
                           if (!Modifier.isStatic(f.getModifiers()) && !f.isSynthetic() && f.getName().indexOf("this$") == -1) {
                              r = r + f.getName() + "=";

                              try {
                                 Object val = f.get(obj);
                                 r = r + toString(val);
                              } catch (Exception var9) {
                                 Exception e = var9;
                                 e.printStackTrace();
                              }

                              r = r + ",";
                           }
                        }

                        comma = ",";
                        if (r.endsWith(comma)) {
                           r = r.substring(0, r.length() - 1);
                        }

                        r = r + "]";
                        cl = cl.getSuperclass();
                     } else {
                        cl = cl.getSuperclass();
                     }
                  } while(cl != null);

                  return r;
               }
            }
         }
      }
   }
}
